@@ -8,20 +8,29 @@ from jasmine_zinc import (
 def main():
     import argparse
     parser = argparse.ArgumentParser()
-    parser.add_argument('cid', type=int)
-    parser.add_argument('talktext', type=str)
+    parser.add_argument('-cid', '--cid', type=int, required=True)
+    parser.add_argument('-t', '--talktext', type=str)
+    parser.add_argument('-f', '--talkfile', type=str)
     parser.add_argument('--server-url', type=str, default=os.environ.get('SERVER_URL'), help='AssistantSeika HTTP Server')
     parser.add_argument('--timeout', type=float, default=3)
     add_talk_arguments(parser=parser)
     args = parser.parse_args()
 
-    cid = args.cid
-    talktext = args.talktext
     server_url = args.server_url
     timeout = args.timeout
 
     assert server_url is not None, 'Server URL must be specified (option --server-url or env var SERVER_URL).'
 
+    cid = args.cid
+    talktext = args.talktext
+    talkfile = args.talkfile
+
+    assert (talktext is not None) ^ (talkfile is not None), 'One of --talktext or --talkfile is required.'
+
+    if talkfile:
+        with open(talkfile, 'r') as fp:
+            talktext = fp.read()
+
     result = talk_on_server(
         server_url=server_url,
         cid=cid,
